@@ -134,7 +134,8 @@ def _dynamically_collapsed_pwd():
         # if there is not even a single separator we still
         # want to display at least the beginning of the directory
         if full.find(sep) == -1:
-            full = (truncature_char + sep + last)[0:int(target_width)]
+            full = (truncature_char + sep +
+                    last)[0:int(target_width) - len(truncature_char)] + truncature_char
     return full
 
 #
